==> responsive_property-0.0.1.tar.gz: lib/src/screen_scope.dart <==
import 'package:flutter/material.dart';

const double screenMaxDimension = 100000;

const double mobileScreenWidthTypical = 360;
const double tabletScreenWidthTypical = 600;
const double desktopScreenWidthTypical = 1024.0;

const double mobileScreenWidthLimit = 480.0;
const double tabletScreenWidthLimit = 840.0;
const double desktopScreenWidthLimit = 2000.0;

const typicalMobileScreenScope = ScreenScope(maxWidth: mobileScreenWidthLimit);
const typicalTabletScreenScope = ScreenScope(
    minWidth: mobileScreenWidthLimit, maxWidth: tabletScreenWidthLimit);
const typicalDesktopScreenScope = ScreenScope(minWidth: tabletScreenWidthLimit);

class ScreenScope {
  final double minWidth;
  final double maxWidth;
  final double minHeight;
  final double maxHeight;

  const ScreenScope({
    this.minWidth = 0.0,
    this.maxWidth = screenMaxDimension,
    this.minHeight = 0.0,
    this.maxHeight = screenMaxDimension,
  }) : assert(minWidth >= 0.0 &&
            minWidth <= maxWidth &&
            maxWidth <= screenMaxDimension &&
            minHeight >= 0.0 &&
            minHeight <= maxHeight &&
            maxHeight <= screenMaxDimension);

  /*
  static fromJson(Map<String, dynamic> map) {
    double minWidth = map["minWidth"] ?? 0.0;
    double maxWidth = map["maxWidth"] ?? screenMaxDimension;
    double minHeight = map["minHeight"] ?? 0.0;
    double maxHeight = map["maxHeight"] ?? screenMaxDimension;
    return ScreenScope(
      maxWidth: maxWidth,
      minWidth: minWidth,
      maxHeight: maxHeight,
      minHeight: minHeight,
    );
  }
  */

  Map<String, dynamic> toJson() {
    Map<String, dynamic> rst = {};
    rst["minWidth"] = minWidth;
    rst["maxWidth"] = maxWidth;
    rst["minHeight"] = minHeight;
    rst["maxHeight"] = maxHeight;

    return rst;
  }

  bool isOfScreenScope(MediaQueryData data) {
    Size size = data.size;
    if (minWidth > size.width ||
        minHeight > size.height ||
        maxWidth < size.width ||
        maxHeight < size.height) {
      return false;
    }
    return true;
  }

  @override
  bool operator ==(Object other) {
    if (other is ScreenScope) {
      if (this.minWidth == other.minWidth &&
          this.maxWidth == other.maxWidth &&
          this.minHeight == other.minHeight &&
          this.maxHeight == other.maxHeight) {
        return true;
      }
    }
    return false;
  }

  @override
  int get hashCode => hashValues(minWidth, maxWidth, minHeight, maxHeight);
}

==> responsive_property-0.0.3.tar.gz: lib/src/screen_scope.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_class_parser/flutter_class_parser.dart';

const double screenMaxDimension = 999999;

class ScreenScope {
  final double minWidth;
  final double maxWidth;
  final double minHeight;
  final double maxHeight;
  final Orientation? orientation;

  const ScreenScope({
    this.minWidth = 0.0,
    this.maxWidth = screenMaxDimension,
    this.minHeight = 0.0,
    this.maxHeight = screenMaxDimension,
    this.orientation,
  }) : assert(minWidth >= 0.0 &&
            minWidth <= maxWidth &&
            maxWidth <= screenMaxDimension &&
            minHeight >= 0.0 &&
            minHeight <= maxHeight &&
            maxHeight <= screenMaxDimension);

  Map<String, dynamic> toJson() {
    Map<String, dynamic> rst = {};
    rst["minWidth"] = minWidth;
    rst["maxWidth"] = maxWidth;
    rst["minHeight"] = minHeight;
    rst["maxHeight"] = maxHeight;
    rst.updateNotNull("orientation", orientation?.toJson());

    return rst;
  }

  bool isOfScreenScope(MediaQueryData data) {
    Size size = data.size;
    if (minWidth > size.width ||
        minHeight > size.height ||
        maxWidth < size.width ||
        maxHeight < size.height) {
      return false;
    }
    if (orientation != null && data.orientation != orientation) {
      return false;
    }
    return true;
  }

  @override
  bool operator ==(Object other) {
    if (other is ScreenScope) {
      if (this.minWidth == other.minWidth &&
          this.maxWidth == other.maxWidth &&
          this.minHeight == other.minHeight &&
          this.maxHeight == other.maxHeight &&
          this.orientation == other.orientation) {
        return true;
      }
    }
    return false;
  }

  @override
  int get hashCode =>
      hashValues(minWidth, maxWidth, minHeight, maxHeight, orientation);
}
